#
# spec file for package drumstick (Version 1.0.2)
#
# MIDI Sequencer C++ Library Bindings for Qt5 and ALSA
# Copyright (C) 2005-2010 Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
#
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#

Name:           drumstick
Version:        1.0.2
Release:        3.4
License:        GPL-2.0+ and GPL-3.0+
Summary:        MIDI Sequencer C++ Library Bindings
Group:          Productivity/Multimedia/Sound/Midi
URL:            http://drumstick.sourceforge.net/
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM gcc6-fix.patch wbauer@tmo.at -- fix build with gcc6
Patch:          gcc6-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  alsa-devel
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  update-desktop-files
BuildRequires:  libxslt
BuildRequires:  docbook_4
BuildRequires:  docbook-xsl-stylesheets
Requires(post):    shared-mime-info
Requires(postun):  shared-mime-info
BuildRequires:  kf5-filesystem

%description
This package includes test and example programs for drumstick libraries.

%package -n libdrumstick-file1
Summary:        MIDI Sequencer C++ Library
Group:          System/Libraries

%description -n libdrumstick-file1
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes classes providing file input and output in formats 
commonly used by MIDI programs. Currently, SMF (standard MIDI file) 
read/write and WRK (Cakewalk) file read are supported. This library does not 
depend on ALSA.

%package -n libdrumstick-alsa1
Summary:        MIDI Sequencer C++ Library
Group:          System/Libraries

%description -n libdrumstick-alsa1
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes the ALSA Sequencer library classes, providing MIDI 
recording and playback functionality to C++/Qt5 programs.

%package -n libdrumstick-devel
Summary:        Development package for the libdrumstick library
Group:          Development/Libraries/C and C++
Requires:       libdrumstick-file1 = %{version}
Requires:       libdrumstick-alsa1 = %{version}
Requires:       glibc-devel libstdc++-devel alsa-devel pkgconfig(Qt5Core)

%description -n libdrumstick-devel
This package contains the files needed to compile programs that use the
libdrumstick libraries.

%package -n libdrumstick-doc
Summary:        Development documentation package for the drumstick libraries
Group:          Documentation/Other
BuildArch:      noarch

%description -n libdrumstick-doc
This package contains the developer's documentation of the drumstick libraries.

%prep
%setup -q
%patch -p0

%build
%cmake_kf5  -- -DSTATIC_DRUMSTICK=0
%make_jobs 
make doxygen

%install
make install DESTDIR=$RPM_BUILD_ROOT
%suse_update_desktop_file -n drumstick-drumgrid Midi
%suse_update_desktop_file -n drumstick-guiplayer Midi
%suse_update_desktop_file -n drumstick-vpiano Midi

%post 
%mime_database_post
/sbin/ldconfig

%postun
%mime_database_postun
/sbin/ldconfig

%post -n libdrumstick-file1 -p /sbin/ldconfig

%postun -n libdrumstick-file1 -p /sbin/ldconfig

%post -n libdrumstick-alsa1 -p /sbin/ldconfig

%postun -n libdrumstick-alsa1 -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc AUTHORS COPYING NEWS README TODO ChangeLog
%doc %{_mandir}/man1/%name-*.1.gz
%{_datadir}/icons/hicolor/*/apps/%name.png
%{_datadir}/icons/hicolor/scalable/apps/%name.svgz
%{_datadir}/applications/%name-*.desktop
%{_bindir}/%name-*
%_libdir/drumstick/
%_libdir/libdrumstick-rt.so.*

%files -n libdrumstick-file1
%defattr(-,root,root)
%{_libdir}/libdrumstick-file.so.*
%{_datadir}/mime/packages/%name.xml

%files -n libdrumstick-alsa1
%defattr(-,root,root)
%{_libdir}/libdrumstick-alsa.so.*

%files -n libdrumstick-devel
%defattr(-, root, root)
%dir %{_includedir}/%name
%{_libdir}/libdrumstick-file.so
%{_libdir}/libdrumstick-alsa.so
%{_includedir}/%name.h
%{_includedir}/%name/*.h
%_libdir/libdrumstick-rt.so
%{_libdir}/pkgconfig/%name-*.pc

%files -n libdrumstick-doc
%defattr(-, root, root)
%doc doc/html/*

%changelog
* Fri Jun 17 2016 jengelh@inai.de
- Drop archaic sections, set rpm groups
* Fri Jun 17 2016 wbauer@tmo.at
- The devel package requires libQt5Core-devel now, not libqt4-devel
* Fri Jun 17 2016 wbauer@tmo.at
- Add gcc6-fix.patch to fix build with gcc6
* Wed Jun 15 2016 wbauer@tmo.at
- Use shared-mime-database macros (boo#979301)
* Tue Apr 12 2016 tittiatcoke@gmail.com
- Update to version 1.0.2
  * Qt5 port.
- Drop x11.diff. No longer required.
* Sun Nov 13 2011 alinm.elena@gmail.com
- fixed x11 failure to link in 12.1 added x11.diff patch
- moved to cmake_kde4 macro
* Thu Feb 17 2011 javier@opensuse.org
- switch to %%{?_smp_mflags}, remove additional optflags,
  clean package file list
* Wed Feb 16 2011 javier@opensuse.org
- fix package file list
* Wed Feb 16 2011 javier@opensuse.org
- copy package from home:plcl and clean spec a bit
